@@ -127,10 +127,10 @@ impl UrlPatternInit {
         if !base_url.cannot_be_a_base()
           && !is_absolute_pathname(pathname, &kind)
         {
-          let baseurl_pathname = url::quirks::pathname(base_url);
-          let slash_index = baseurl_pathname.rfind('/');
+          let baseurl_path = url::quirks::pathname(base_url);
+          let slash_index = baseurl_path.rfind('/');
           if let Some(slash_index) = slash_index {
-            let new_pathname = baseurl_pathname[..=slash_index].to_string();
+            let new_pathname = baseurl_path[..=slash_index].to_string();
             result.pathname =
               Some(format!("{}{}", new_pathname, result.pathname.unwrap()));
           }
@@ -292,7 +292,7 @@ impl UrlPattern {
     } else {
       Component::compile(
         processed_init.pathname.as_deref(),
-        canonicalize_and_process::canonicalize_cannot_be_a_base_url_pathname,
+        canonicalize_and_process::canonicalize_an_opaque_pathname,
         parser::Options::default(),
       )?
       .optionally_transpose_regex_error(report_regex_errors)?
@@ -579,6 +579,8 @@ mod tests {
 
   #[derive(Debug, Deserialize)]
   struct MatchResult {
+    #[serde(deserialize_with = "deserialize_match_result_inputs")]
+    #[serde(default)]
     inputs: Option<(quirks::StringOrInit, Option<String>)>,
 
     protocol: Option<ComponentResult>,
@@ -591,8 +593,29 @@ mod tests {
     hash: Option<ComponentResult>,
   }
 
+  fn deserialize_match_result_inputs<'de, D>(
+    deserializer: D,
+  ) -> Result<Option<(quirks::StringOrInit, Option<String>)>, D::Error>
+  where
+    D: serde::Deserializer<'de>,
+  {
+    #[derive(Debug, Deserialize)]
+    #[serde(untagged)]
+    enum MatchResultInputs {
+      OneArgument((quirks::StringOrInit,)),
+      TwoArguments(quirks::StringOrInit, String),
+    }
+
+    let res = Option::<MatchResultInputs>::deserialize(deserializer)?;
+    Ok(match res {
+      Some(MatchResultInputs::OneArgument((a,))) => Some((a, None)),
+      Some(MatchResultInputs::TwoArguments(a, b)) => Some((a, Some(b))),
+      None => None,
+    })
+  }
+
   fn test_case(case: TestCase) {
-    let input = case.pattern.get(0).unwrap().clone();
+    let input = case.pattern.get(0).cloned();
     let mut base_url = case.pattern.get(1).map(|input| match input {
       StringOrInit::String(str) => str.clone(),
       StringOrInit::Init(_) => unreachable!(),
@@ -610,6 +633,8 @@ mod tests {
       return;
     }
 
+    let input = input.unwrap_or_else(|| StringOrInit::Init(Default::default()));
+
     let init_res = quirks::process_construct_pattern_input(
       input.clone(),
       base_url.as_deref(),
@@ -701,7 +726,7 @@ mod tests {
     assert_field!(search);
     assert_field!(hash);
 
-    let input = case.inputs.get(0).unwrap().clone();
+    let input = case.inputs.get(0).cloned();
     let base_url = case.inputs.get(1).map(|input| match input {
       StringOrInit::String(str) => str.clone(),
       StringOrInit::Init(_) => unreachable!(),
@@ -713,6 +738,10 @@ mod tests {
       serde_json::to_string(&base_url).unwrap(),
     );
 
+    let input = input.unwrap_or_else(|| StringOrInit::Init(Default::default()));
+
+    let expected_input = (input.clone(), base_url.clone());
+
     let match_input = quirks::process_match_input(input, base_url.as_deref());
 
     if let Some(ExpectedMatch::String(s)) = &case.expected_match {
@@ -735,7 +764,7 @@ mod tests {
     } else {
       Ok(false)
     };
-    let exec_res = if let Some((input, _)) = input {
+    let exec_res = if let Some((input, _)) = input.clone() {
       pattern.exec(input)
     } else {
       Ok(None)
@@ -774,6 +803,12 @@ mod tests {
 
     let actual_match = actual_match.expect("expected match to be Some");
 
+    let expected_inputs = expected_match.inputs.unwrap_or(expected_input);
+
+    let (_, inputs) = input.unwrap();
+
+    assert_eq!(inputs, expected_inputs, "expected inputs to be identical");
+
     let exactly_empty_components = case.exactly_empty_components;
 
     macro_rules! convert_result {
